import contextlib
import wave
import py_webrtcrnnvad
import numpy as np

def read_wave(path):
    """Reads a .wav file.
    Takes the path, and returns (PCM audio data, sample rate).
    """
    with contextlib.closing(wave.open(path, 'rb')) as wf:
        num_channels = wf.getnchannels()
        assert num_channels == 1
        sample_width = wf.getsampwidth()
        assert sample_width == 2
        sample_rate = wf.getframerate()
        assert sample_rate in (8000, 16000, 32000, 48000)
        pcm_data = wf.readframes(wf.getnframes())
        return pcm_data, sample_rate
    
class Frame(object):
    """Represents a "frame" of audio data."""
    def __init__(self, bytes, timestamp, duration):
        self.bytes = bytes
        self.timestamp = timestamp
        self.duration = duration


def frame_generator(frame_duration_ms, audio, sample_rate):
    """Generates audio frames from PCM audio data.
    Takes the desired frame duration in milliseconds, the PCM data, and
    the sample rate.
    Yields Frames of the requested duration.
    """
    n = int(sample_rate * (frame_duration_ms / 1000.0) * 2)
    offset = 0
    timestamp = 0.0
    duration = (float(n) / sample_rate) / 2.0
    while offset + n < len(audio):
        yield Frame(audio[offset:offset + n], timestamp, duration)
        timestamp += duration
        offset += n

audio, fs = read_wave("audio.wav")
frames = frame_generator(10, audio, 48000)
vad = py_webrtcrnnvad.RNNVAD()
vad_probs = []
for frame in frames:
    frame_short = np.frombuffer(frame.bytes, dtype=np.short)
    vad_probs += [vad.processFrame(frame_short.astype(np.float32))]

import matplotlib.pyplot as plt
plt.plot(np.array(condition))


from ._py_webrtcrnnvad import *

__version__ = "0.0.1"

class RNNVAD:
    """
    This is class of WebRTC RNNVAD
    based on https://jmvalin.ca/demo/rnnoise/
    """
    def __init__(self):
        self.st = rnnoise_create()
    
    def processFrame(self, frame):
        """
        :param frame: (np.ndarray) frame of 48k audio range is -32767.0 ~ 32768.0 
        dtype is float32, frame lenghth should be 480 
        """
        assert frame.shape==(480,)
        return rnnvad_process_npframe(self.st, frame)
    
    def reset(self):
        """ """
        rnnoise_destory(self.st)
        self.st = rnnoise_create()